pub fn build_dendrogram(g: &Graph) -> DendrogramExpand description
Build the full dendrogram by repeated Louvain + coarsening, stopping when a round no longer compresses the graph (or only one node remains).
pub fn build_dendrogram(g: &Graph) -> DendrogramBuild the full dendrogram by repeated Louvain + coarsening, stopping when a round no longer compresses the graph (or only one node remains).