write_file

Function write_file 

pub fn write_file(
    dict: &Dictionary,
    index: &GraphIndex,
    has_quads: bool,
    pyramid_meta: &[u8],
    pyramid_levels: u16,
) -> Vec<u8> ⓘ
Serialize a complete .rete file image from a dictionary, index, and an (optionally empty) encoded pyramid-meta section. pyramid_levels records the number of dendrogram rounds the pyramid spans (0 if no pyramid).