pub type ObjectId = u32;Expand description
A dictionary id in the object id space (terms seen in object position).
Map to a NodeId with Dictionary::object_node.
pub type ObjectId = u32;A dictionary id in the object id space (terms seen in object position).
Map to a NodeId with Dictionary::object_node.