pub type SubjectId = u32;Expand description
A dictionary id in the subject id space (terms seen in subject
position). Map to a NodeId with Dictionary::subject_node.
pub type SubjectId = u32;A dictionary id in the subject id space (terms seen in subject
position). Map to a NodeId with Dictionary::subject_node.